from setuptools import *
setup(name="pysbs", version="1.0.0", author="wer310Libs", author_email="oficalkapudovo@gmail.com", description="Library for ooen and write .sbs files", packages=find_packages())

